
//var storage = localStorage;
var storage = sessionStorage;

//function getContentWidth(titleW, blocks, blockW) {
//	return titleW + blockW * blocks + 30;
//}
function getContentWidth() {
	if(_isEmpty(storage.getItem("_TitleW"))){
		storage.setItem("_TitleW", getTitleWidth());
	}
        if(_isEmpty(storage.getItem("_BlockW"))){
                storage.setItem("_BlockW","10");
        }
        if(_isEmpty(storage.getItem("_Block"))){
                storage.setItem("_Block","100");
        }
	return parseInt(storage.getItem("_TitleW")) + parseInt(storage.getItem("_BlockW")) * parseInt(storage.getItem("_Block")) + 60;
}
function getTitleWidth() {
	var en=new Object(JSON.parse(storage.getItem("_Env")));
	if(!_isEmpty(en.accession_cvs_width)){
		return parseInt(en.accession_cvs_width);
	} else if(storage.getItem("_Name") == "id"){
		return 180;
	} else {
		return 220;
	}
}
